summaryrefslogtreecommitdiffstats
path: root/tools/misc/h5repart.c
diff options
context:
space:
mode:
authorRaymond Lu <songyulu@hdfgroup.org>2005-06-02 21:00:23 (GMT)
committerRaymond Lu <songyulu@hdfgroup.org>2005-06-02 21:00:23 (GMT)
commit769694294033cf2021b506cde1302af5fdb2ebff (patch)
tree6eb63c4e19e009f217164f91d16250cb21edbbc5 /tools/misc/h5repart.c
parentc02d9c7c0d4e526837445306bb35eb108db92ff5 (diff)
downloadhdf5-769694294033cf2021b506cde1302af5fdb2ebff.zip
hdf5-769694294033cf2021b506cde1302af5fdb2ebff.tar.gz
hdf5-769694294033cf2021b506cde1302af5fdb2ebff.tar.bz2
[svn-r10847] Purpose: Bug fix
Description: See details from Bug #213. Family member file size wasn't saved anywhere in file. When family file is opened, the first member size determine the member size. Solution: This is the fourth step of checkin. A test suit is added for h5repart, including a program to generate the test files, a script file to run h5repart, and a program to verify repartitioned files can be opened by the library. There's a change from the first step of checkin. Family name template is no longer saved in the superblock because different pathname can make the name different. In the third step of checkin, h5repart has been modified. If h5repart is used to change the size of family member file, the new size(actual member size) is saved in the superblock. In the second step of checkin, multi driver is checked against the driver name saved in superblock. Wrong driver will result in a failure with an error message indicating multi driver should be used. This change includes split driver because it's a special case for multi driver. In the first step of checkin. Family member size and name template(unused at this stage) are saved in file superblock. When file is reopened,the size passed in thrin superblock. A different size will trigger a failure with an error message indicating the right size. Wrong driver to open family file will cause a failure, too. Platforms tested: h5committest and fuss. Misc. update: MANIFEST
Diffstat (limited to 'tools/misc/h5repart.c')
-rw-r--r--tools/misc/h5repart.c23
1 files changed, 17 insertions, 6 deletions
diff --git a/tools/misc/h5repart.c b/tools/misc/h5repart.c
index 0bd2dd8..6803aae 100644
--- a/tools/misc/h5repart.c
+++ b/tools/misc/h5repart.c
@@ -65,6 +65,10 @@
# define MIN3(X,Y,Z) MIN(MIN(X,Y),Z)
#endif
+/*Make this private property(defined in H5Fprivate.h) available to h5repart,
+ *to update the member file size in the superblock.*/
+#define H5F_ACS_FAMILY_NEWSIZE_NAME "family_newsize"
+
/*-------------------------------------------------------------------------
* Function: usage
@@ -223,7 +227,7 @@ main (int argc, char *argv[])
off_t src_act_size; /*source actual member size */
off_t dst_size=1 GB; /*destination logical memb size */
#endif
- hid_t fapl;
+ hid_t fapl; /*file access property list */
hid_t file;
/*
@@ -444,19 +448,26 @@ main (int argc, char *argv[])
}
close (dst);
/* modify family size saved in superblock. Member size 1 signals library to
* save the new size(actual member file size) in superblock. It's for this
* tool only. */
if ((fapl=H5Pcreate(H5P_FILE_ACCESS))<0) {
perror ("H5Pcreate");
exit (1);
}
-
- if(H5Pset_fapl_family(fapl, 1, H5P_DEFAULT)<0) {
+
+ if(H5Pset_fapl_family(fapl, H5F_FAMILY_DEFAULT, H5P_DEFAULT) < 0) {
perror ("H5Pset_fapl_family");
exit (1);
}
+
+ if(H5Pset(fapl, H5F_ACS_FAMILY_NEWSIZE_NAME, &dst_size) < 0) {
+ perror ("H5Pset_family_newsize");
+ exit (1);
+ }
+ /* Open file for "read and write" to flush metadata. Flushing metadata
+ * will update the superblock to the new member size. */
if((file=H5Fopen(dst_gen_name, H5F_ACC_RDWR, fapl))<0) {
perror ("H5Fopen");
exit (1);
@@ -444,19 +448,26 @@ main (int argc, char *argv[])
}
close (dst);
- /* modify family size saved in superblock. Member size 1 signals library to
- * save the new size(actual member file size) in superblock. It's for this
- * tool only. */
+ /* Modify family size saved in superblock through private property. It signals
+ * library to save the new member size(specified in command line) in superblock.
+ * This private property is for this tool only. */
if ((fapl=H5Pcreate(H5P_FILE_ACCESS))<0) {
perror ("H5Pcreate");